@@ -1,14 +1,18 @@
-#' Function for plotting category probabilities of multinomial log-linear regression model
+#' Plot category probabilities of multinomial model
 #'
 #' @aliases plotMultinomial
 #'
-#' @description Plots category probabilities functions estimated by \code{multinom()} from \code{nnet} package.
+#' @description Plots category probabilities functions estimated by
+#'   \code{multinom()} from the \code{nnet} package using the \pkg{ggplot2}
+#'   package.
 #'
 #' @param x object of class \code{multinom}
-#' @param matching numeric: vector of matching criterion used for estimation in \code{x}.
-#' @param matching.name character: name of matching criterion used for estimation in \code{x}.
+#' @param matching numeric: vector of matching criterion used for estimation in
+#'   \code{x}.
+#' @param matching.name character: name of matching criterion used for
+#'   estimation in \code{x}.
 #'
-#' @usage plotMultinomial(x, matching, matching.name = "matching")
+#' @return An object of class \code{ggplot} and/or \code{gg}.
 #'
 #' @author
 #' Adela Hladka \cr
@@ -17,6 +21,7 @@
 #' \email{hladka@@cs.cas.cz} \cr
 #'
 #' Tomas Jurica \cr
+#' Institute of Computer Science of the Czech Academy of Sciences \cr
 #'
 #' Patricia Martinkova \cr
 #' Institute of Computer Science of the Czech Academy of Sciences \cr
@@ -29,12 +34,10 @@
 #' # loading data
 #' data(GMAT, GMATtest, GMATkey, package = "difNLR")
 #'
-#' matching <- scale(apply(GMAT[, 1:20], 1, sum)) # Z-score
-#' data <- GMATtest[, 1:20]
-#' key <- GMATkey
+#' matching <- scale(rowSums(GMAT[, 1:20])) # Z-score
 #'
 #' # multinomial model for item 1
-#' fit <- nnet::multinom(relevel(data[, 1], ref = paste(key[1])) ~ matching)
+#' fit <- nnet::multinom(relevel(GMATtest[, 1], ref = paste(GMATkey[1])) ~ matching)
 #'
 #' # plotting category probabilities
 #' plotMultinomial(fit, matching, matching.name = "Z-score")
@@ -59,26 +62,28 @@ plotMultinomial <- function(x, matching, matching.name = "matching") {
     matching <- matching[-as.vector(x$na.action)]
   }
 
-  match <- seq(min(matching, na.rm = T), max(matching, na.rm = T), length.out = 300) # matching for curves
+  match <- seq(min(matching, na.rm = TRUE), max(matching, na.rm = TRUE), length.out = 1000) # matching for curves
   coefs <- matrix(coef(x), ncol = 2)
 
   # calculation of fitted curves
   df.probs <- data.frame(1, apply(coefs, 1, function(x) exp(x[1] + x[2] * match)))
-  df.probs <- df.probs / apply(df.probs, 1, sum)
+  df.probs <- df.probs / rowSums(df.probs)
   df.probs <- data.frame(match, df.probs)
   colnames(df.probs) <- c("matching", paste0("P(Y=", cat, ")"))
-  df.probs <- melt(df.probs, id.vars = "matching", variable.name = "category", value.name = "probability")
+  df.probs <- tidyr::pivot_longer(df.probs, -matching, names_to = "Category", values_to = "Probability")
+  df.probs$Category <- relevel(as.factor(df.probs$Category), paste0("P(Y=", cat[1], ")"))
+  colnames(df.probs)[1] <- "Matching"
 
   # calculation of empirical values
   df.emp <- data.frame(table(y, matching),
     y = prop.table(table(y, matching), 2)
   )[, c(1, 2, 3, 6)]
   df.emp$matching <- as.numeric(paste(df.emp$matching))
-  colnames(df.emp) <- c("category", "matching", "size", "probability")
-  df.emp$category <- paste0("P(Y=", df.emp$category, ")")
-  df.emp$category <- factor(df.emp$category, levels = levels(df.probs$category))
+  colnames(df.emp) <- c("Category", "Matching", "Count", "Probability")
+  df.emp$Category <- paste0("P(Y=", df.emp$Category, ")")
+  df.emp$Category <- relevel(as.factor(df.emp$Category), paste0("P(Y=", cat[1], ")"))
 
-  num.cat <- length(levels(df.probs$category))
+  num.cat <- length(levels(df.probs$Category))
   k1 <- num.cat %/% 12
   k2 <- ifelse(num.cat < 12, num.cat, num.cat - 12)
   linetypes <- c(rep(1:12, k1), c(1:12)[1:k2])
@@ -88,18 +93,18 @@ plotMultinomial <- function(x, matching, matching.name = "matching") {
     geom_point(
       data = df.emp,
       aes_string(
-        x = "matching", y = "probability",
-        colour = "category", fill = "category", size = "size"
+        x = "Matching", y = "Probability",
+        colour = "Category", fill = "Category", size = "Count"
       ),
       alpha = 0.5, shape = 21
     ) +
     geom_line(
       data = df.probs,
       aes_string(
-        x = "matching", y = "probability",
-        colour = "category", linetype = "category"
+        x = "Matching", y = "Probability",
+        colour = "Category", linetype = "Category"
       ),
-      size = 1
+      size = 0.8
     ) +
     ylim(0, 1) +
     labs(
